// PrestoChannelFactory.cs
//
// PRESTO Starter Kit for Microsoft .NET 3.0
// 2007 Microsoft France
// Published under the CECILL-B Free Software license agreement.
// (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
// 
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// WHETHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE. 
// THE ENTIRE RISK OF USE OR RESULTS IN CONNECTION WITH THE USE OF THIS CODE 
// AND INFORMATION REMAINS WITH THE USER. 
//

using System;
using System.Configuration;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Text;
using System.Xml;
using System.Xml.Serialization;
using System.ServiceModel;
using System.ServiceModel.Channels;
using System.ServiceModel.Configuration;
using System.ServiceModel.Description;

namespace Microsoft.Presto.StarterKit.NonNormative
{
    public class PrestoChannelFactory
    {
        private INonNormativePresto proxy;

        public PrestoChannelFactory()
        {
            WSHttpBinding binding = new WSHttpBinding();
            binding.Security.Mode = SecurityMode.None;

            EndpointAddress endpointAddress = new EndpointAddress("urn:PrestoProxyEndpoint");
            ChannelFactory<INonNormativePresto> channelFactory = new ChannelFactory<INonNormativePresto>(binding);
            Uri via = new Uri(ConfigurationManager.AppSettings["viaAddress"]);
            proxy = channelFactory.CreateChannel(endpointAddress, via);
        }

        public void Submit1Message(string payload)
        {
            try
            {
                string response = proxy.submit1("payload");
                OutputTrace.Log("Submit1 call succeeded w/errors");
            }
            catch (Exception ex)
            {
                LogException(ex);
            }
        }

        public void Submit2Message(string payload)
        {
            try
            {
                string response = proxy.submit2("payload");
                OutputTrace.Log("Submit2 call  succeeded w/errors");
            }
            catch (Exception ex)
            {
                LogException(ex);
            }
        }

        private void LogException(Exception ex)
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("An error has been encountered: \n" 
                       + "Type : " + ex.GetType().ToString() + "\n" 
                       + ex.Message + "\n" + ex.StackTrace);
            OutputTrace.Log(sb.ToString());
            
            if (ex.InnerException != null)
            {
                StringBuilder sbInner = new StringBuilder();
                sbInner.Append("An error has been encountered: \n"
                              + "Type : " + ex.InnerException.GetType().ToString() + "\n"
                              + ex.InnerException.Message + "\n" + ex.InnerException.StackTrace);
                OutputTrace.Log(sbInner.ToString());
            }
        }
    }
}