// TargetApplication.cs
//
// PRESTO Starter Kit for Microsoft .NET 3.0
// 2007 Microsoft France
// Published under the CECILL-B Free Software license agreement.
// (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
// 
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// WHETHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE. 
// THE ENTIRE RISK OF USE OR RESULTS IN CONNECTION WITH THE USE OF THIS CODE 
// AND INFORMATION REMAINS WITH THE USER. 
//

using System;
using System.Configuration;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Diagnostics;
using System.Text;
using System.IO;
using System.Threading;
using System.Windows.Forms;

namespace Microsoft.Presto.StarterKit
{
    public partial class formTargetApplication : Form
    {
        private PrestoSoapNodeConfig config = new PrestoSoapNodeConfig();
        private PrestoServiceHost serviceHost = new PrestoServiceHost();
        
        public formTargetApplication()
        {
            InitializeComponent();

            // Service endpoint base addresses
            config.ServiceEndpointUri = ConfigurationManager.AppSettings["baseAddress"];
            config.ServiceEndpointMexUri = ConfigurationManager.AppSettings["baseMexAddress"];
            config.SoapIntermediaryEndpointUri = ConfigurationManager.AppSettings["baseListenToAddress"];

            // Service credentials
            config.ServiceCertificateThumbprint = ConfigurationManager.AppSettings["certificateThumbprint"];

            this.prestoSoapNodeConfigBindingSource.DataSource = config;
            this.serviceHost.Config = config;

            ReceiveFilename.OnNotifyReceive += new ReceiveFilename.NotifyReceive(ReceiveFileName_OnNotifyReceive);
            OutputTrace.OnLogMessage += new OutputTrace.LogDelegate(OutputTrace_OnLogMessage);
            
            textBoxSoapIntermediaryEndpointUri.Enabled = config.UseSoapIntermediary;
        }

        void OutputTrace_OnLogMessage(string message)
        {
            this.BeginInvoke(new OutputTrace.LogDelegate(LogMessage), new object[] {message});           
        }

        private void LogMessage(string message)
        {
            this.richTextBoxTrace.AppendText(Environment.NewLine + message);
        }

        private void buttonStartPrestoInterface_Click(object sender, EventArgs e)
        {
            if (!serviceHost.IsListening)
            {
                serviceHost.StartPrestoInterface();
                this.buttonStartPrestoInterface.Text = "Stop..." ;
            }
            else
            {
                serviceHost.StopPrestoInterface();
                this.buttonStartPrestoInterface.Text = "Start..." ;
            }
        }

        private void buttonClearLog_Click(object sender, EventArgs e)
        {
            this.richTextBoxTrace.Text = "";
        }

        private void checkBoxUseSoapIntermediary_CheckedChanged(object sender, EventArgs e)
        {
            config.UseSoapIntermediary = checkBoxUseSoapIntermediary.Checked;
            textBoxSoapIntermediaryEndpointUri.Enabled = config.UseSoapIntermediary;
        }

        private void EnableManualConfigurationSettings(bool enable)
        {
            this.comboBoxAddressingVersion.Enabled = enable;
            //this.checkBoxUseReliableMessaging.Enabled = enable;
            //this.comboBoxEncodingMode.Enabled = enable;
            this.checkBoxUseSignature.Enabled = enable;
            this.checkBoxUseEncryption.Enabled = enable;
        }

        private void checkBoxUseConfigurationFile_CheckedChanged(object sender, EventArgs e)
        {
            EnableManualConfigurationSettings(!checkBoxUseConfigurationFile.Checked);
        }

        void ReceiveFileName_OnNotifyReceive(string fileName)
        {
            if (checkBoxDisplayMsg.Checked)
                DisplayMessage(Directory.GetCurrentDirectory() + @"\" + fileName);
        }

        private void DisplayMessage(string fileName)
        {
            //Automatic Message close...
            //using (MessageView messageView = new MessageView())
            //{
            //    messageView.Top = 0;
            //    messageView.Left = 0;
            //    messageView.SetBounds(0, 0, this.Width, this.Height);
            //    messageView.Display(fileName);
            //    messageView.Show();
            //    Application.DoEvents();
            //    Thread.Sleep(1000);
            //}

            MessageView messageView = new MessageView();
            messageView.Top = 0;
            messageView.Left = 0;
            messageView.SetBounds(0, 0, this.Width, this.Height);
            messageView.Display(fileName);
            messageView.Show(); 
        
        }

        private void checkBoxUseEncryption_CheckedChanged(object sender, EventArgs e)
        {
            if (checkBoxUseEncryption.Checked)
            {
                checkBoxUseSignature.Checked = true;
                config.UseDigitalSignature = true;

            }
        }

        private void radioButtonNoAuthentication_CheckedChanged(object sender, EventArgs e)
        {
            if (radioButtonNoAuthentication.Checked)
            {
                checkBoxUseSignature.Checked = false;
                checkBoxUseEncryption.Checked = false;
                checkBoxUseSignature.Enabled = false;
                checkBoxUseEncryption.Enabled = false;
            }

        }

        private void radioButtonAnonymousForCertificate_CheckedChanged(object sender, EventArgs e)
        {
            if (radioButtonAnonymousForCertificate.Checked)
            {
                checkBoxUseSignature.Enabled = true;
                checkBoxUseEncryption.Enabled = true;
            }
        }

        private void radioButtonMutualCertificate_CheckedChanged(object sender, EventArgs e)
        {
            if (radioButtonMutualCertificate.Checked)
            {
                checkBoxUseSignature.Enabled = true;
                checkBoxUseEncryption.Enabled = true;
            }
        }
    }
}